mafw.scripts.mafw\_exe
======================

.. automodule:: mafw.scripts.mafw_exe

   
   .. rubric:: Functions

   .. autosummary::
   
      custom_formatwarning
      logger_setup
   
   .. rubric:: Classes

   .. autosummary::
   
      ReturnValue
   